Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(716)

Unified Diff: ui/base/events/event_utils.h

Issue 11411247: Support 3f swipe for tab scrubbing (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/events/event_utils.h
diff --git a/ui/base/events/event_utils.h b/ui/base/events/event_utils.h
index 1e1240ea912337df026ab616f628079ce2baf74b..77e542f04922732094b4f532fb82b7cf6bd0f7c6 100644
--- a/ui/base/events/event_utils.h
+++ b/ui/base/events/event_utils.h
@@ -92,10 +92,11 @@ UI_EXPORT bool GetFlingData(const base::NativeEvent& native_event,
bool* is_cancel);
// Returns whether this is a scroll event and optionally gets the amount to be
// scrolled. |x_offset| and |y_offset| can be NULL.
UI_EXPORT bool GetScrollOffsets(const base::NativeEvent& native_event,
float* x_offset,
- float* y_offset);
+ float* y_offset,
+ int* finger_count);
UI_EXPORT bool GetGestureTimes(const base::NativeEvent& native_event,
double* start_time,
@@ -92,10 +92,11 @@ UI_EXPORT bool GetFlingData(const base::NativeEvent& native_event,
bool* is_cancel);
// Returns whether this is a scroll event and optionally gets the amount to be
-// scrolled. |x_offset| and |y_offset| can be NULL.
+// scrolled. |x_offset|, |y_offset| and |finger_count| can be NULL.
UI_EXPORT bool GetScrollOffsets(const base::NativeEvent& native_event,
float* x_offset,

Powered by Google App Engine
This is Rietveld 408576698